@@ -21,7 +21,8 @@ def cli(ctx: Context, version: bool = False):
 
     ctx.obj = CliConfig.load()
 
-    module_err = f"Use `{ctx.info_name} client install` to set the client module first!" | red
+    module_err = (
+        f"Use `{ctx.info_name} configure client` to set the client module first!" | red)
 
-    if ctx.obj.client_module_name is None and ctx.invoked_subcommand != "client":
+    if ctx.obj.client_module_name is None and ctx.invoked_subcommand != "configure":
         raise click.UsageError(module_err)
