@@ -2,12 +2,12 @@ import click
 from plumbum.colors import green  # noqa: F401
 
 from openapi_cli.config import CliConfig
-from openapi_cli.interfaces.main import cli
-from openapi_cli.symbols import OK
 from openapi_cli.helpers import echo
+from openapi_cli.interfaces.configure import configure
+from openapi_cli.symbols import OK
 
 
-@cli.command("set-editor", no_args_is_help=True)
+@configure.command("editor", no_args_is_help=True)
 @click.argument("editor", type=str)
 @click.pass_obj
 def set_editor(config: CliConfig, editor: str):
